@@ -1,4 +1,3 @@
-
 """
 Rival Regions Wrapper
 
@@ -12,7 +11,7 @@ import pathlib2
 from appdirs import user_data_dir
 
 
-DATA_DIR = user_data_dir('rival_regions_wrapper', 'bergc')
+DATA_DIR = user_data_dir("rival_regions_wrapper", "bergc")
 pathlib2.Path(DATA_DIR).mkdir(parents=True, exist_ok=True)
 
 # get logger
@@ -20,7 +19,7 @@ LOGGER = logging.getLogger(__name__)
 LOGGER.setLevel(logging.DEBUG)
 
 # create file handler
-FILE_HANDLER = logging.FileHandler('{}/output.log'.format(DATA_DIR))
+FILE_HANDLER = logging.FileHandler("{}/output.log".format(DATA_DIR))
 FILE_HANDLER.setLevel(logging.DEBUG)
 
 # create console handler
@@ -28,10 +27,13 @@ STREAM_HANDLER = logging.StreamHandler()
 STREAM_HANDLER.setLevel(logging.INFO)
 
 # create formatter and add it to the handlers
-STREAM_FORMATTER = logging.Formatter('%(name)s - %(module)s - %(levelname)s - %(message)s')
+STREAM_FORMATTER = logging.Formatter(
+    "%(name)s - %(module)s - %(levelname)s - %(message)s"
+)
 STREAM_HANDLER.setFormatter(STREAM_FORMATTER)
-FILE_FORMATTER = logging \
-        .Formatter('%(asctime)s - %(name)s - %(module)s - %(levelname)s - %(message)s')
+FILE_FORMATTER = logging.Formatter(
+    "%(asctime)s - %(name)s - %(module)s - %(levelname)s - %(message)s"
+)
 FILE_HANDLER.setFormatter(FILE_FORMATTER)
 
 # add the handlers to logger
