@@ -6,18 +6,14 @@ from rival_regions_wrapper.wrapper.abstract_wrapper import AbstractWrapper
 
 class LanguageChat(AbstractWrapper):
     """Wrapper class for language chat"""
+
     def __init__(self, middleware, language):
         AbstractWrapper.__init__(self, middleware)
         self.language = language
 
     def message(self, message):
         """send message to language chat"""
-        LOGGER.info('"%s": CHAT: language %s',
-                self.middleware.username,
-                self.language
-            )
-        api.language_message(
-                self.middleware,
-                self.language,
-                message
-            )
+        LOGGER.info(
+            '"%s": CHAT: language %s', self.middleware.username, self.language
+        )
+        api.language_message(self.middleware, self.language, message)
